summaryrefslogtreecommitdiffstats
path: root/qtsharp/src/examples/tutorials/t3.cs
diff options
context:
space:
mode:
Diffstat (limited to 'qtsharp/src/examples/tutorials/t3.cs')
-rw-r--r--qtsharp/src/examples/tutorials/t3.cs12
1 files changed, 6 insertions, 6 deletions
diff --git a/qtsharp/src/examples/tutorials/t3.cs b/qtsharp/src/examples/tutorials/t3.cs
index 26fece72..806c5184 100644
--- a/qtsharp/src/examples/tutorials/t3.cs
+++ b/qtsharp/src/examples/tutorials/t3.cs
@@ -10,16 +10,16 @@ public class Example {
public static int Main (String[] args)
{
- TQApplication a = new TQApplication (args);
+ TTQApplication a = new TTQApplication (args);
- TQVBox box = new TQVBox ();
+ TTQVBox box = new TTQVBox ();
box.Resize (200, 120);
- TQPushButton quit = new TQPushButton ("Quit", box);
- quit.SetFont (new TQFont ("Times", 18, TQFont.Weight.Bold));
- // In C++, TQFont::Bold is sufficient
+ TTQPushButton quit = new TTQPushButton ("Quit", box);
+ quit.SetFont (new TTQFont ("Times", 18, TTQFont.Weight.Bold));
+ // In C++, TTQFont::Bold is sufficient
- TQObject.Connect ( quit, QtSupport.TQT_SIGNAL ("clicked()"), a, QtSupport.TQT_SLOT ("Quit()") );
+ TTQObject.Connect ( quit, QtSupport.TQT_SIGNAL ("clicked()"), a, QtSupport.TQT_SLOT ("Quit()") );
// TQT_SIGNAL and TQT_SLOT are static functions of QtSupport
a.SetMainWidget (box);